@@ -12,11 +12,19 @@ ddata = {
     '挑战房间添加机器人': (547, 226, (128, 61, 16)),
     '挑战房间点击开始': (955, 470, (118, 10, 14)),
     '退出战斗按钮': (985, 13, (159, 71, 78)),
+    '战斗场景设置按钮': (957, 12, (98, 160, 82)),
     '确认退出战斗': (433, 344, (255, 229, 71)),
     '关闭竞技大厅': (914, 43, (255, 231, 120)),
     '打气球开始': (500, 520, (217, 91, 21)),
     '轮到自己回合': (494, 169, (255, 190, 112)),
-    '弹球开始': (400, 509, (0, 88, 58))
+    '弹球开始': (400, 509, (0, 88, 58)),
+    '关闭弹球界面': (941, 67, (255, 238, 215)),
+    '公会活动按钮': (932, 500, (30, 5, 4)),
+    '进入公会boss场景按钮': (603, 552, (86, 35, 35)),
+    '公会boss场景右下角返回': (971, 585, (255, 255, 255)),
+    '公会boss场景右上角按钮显示': (979, 37, (255, 234, 217)),
+    '公会boss场景右上角按钮隐藏': (979, 37, (118, 37, 30)),
+    '弹岛开始': (484, 522, (215, 154, 115))
 }
 
 if __name__ == '__main__':
